==> csx600_m512_le_base_RHE4_64-2.24.tgz: opt/clearspeed/csx600_m512_le/bin/run_tests.pl <==
#!/usr/bin/perl

use strict;
use Getopt::Std;

my %opts;

getopts('vi:', \%opts) || usage();

my $path;
my $bin;
my $csx;
my $verbose;
my $logfile;
my $instance;
my $os;

if ($ENV{'OS'} eq "Windows_NT" ) 
{
  $path=$ENV{'CSHOME'}."/";
  $bin="bin/";
  $csx="csx/";
  $verbose=0;
  $logfile="test.log";
  $instance=0;
  $os="Windows";
}
else
{
  $path=$ENV{'CSHOME'}."/";
  $bin="bin/";
  $csx="csx/";
  $verbose=0;
  $logfile="test.log";
  $instance=0;
  $os="Linux";
}

if (defined $opts{'v'}) { $verbose=1; }
if (defined $opts{'i'}) { $instance=$opts{'i'}; }

if (-f $logfile) { unlink($logfile); }

# no longer needed - DMA is always on now
#$ENV{'CS_USE_DMA'} = 1;

# Order is important as test rely on the previous components working

# Check bashrc has been sourced
if ($path eq "\/") 
{
  if ($os eq "Windows") { print(STDOUT "Environment not set up correctly.\n"); }
  else { print(STDOUT "Please source bashrc !\n"); }
  exit -1; 
}

# Board existence check
# run existence check with dma off and interrupts off for max robustness
# those features are tested later
print(STDOUT "Board existence check (~2 seconds)");
checkFile($path."adbgt_scripts/board_exists.scr");
if ($os eq "Windows") 
{
  $ENV{'LLDINST'}=$instance;
  $ENV{'CS_DISABLE_DMA'} = 1;
  runTest($path.$bin."adbgt","--path \"$ENV{'CSHOME'}/adbgt_scripts\" -c board_exists.scr --noint","");
  delete $ENV{'LLDINST'};
  delete $ENV{'CS_DISABLE_DMA'};
}
else
{
  runTest("CS_DISABLE_DMA=1 LLDINST=$instance ".$path.$bin."adbgt","--path $ENV{'CSHOME'}/adbgt_scripts -c board_exists.scr --noint","");
}


# Check that csreset works properly
print(STDOUT "Driver reset test (~2 seconds)");
runTest($path.$bin."csreset","-A -i $instance -v","");


# IO engine test
print(STDOUT "IO Engine test chip 0 (~20 seconds)");
checkFile($path.$csx."ev5_bringup_io_engine_test_0.csx");
checkFile($path.$csx."ev5_bringup_io_engine_test_1.csx");
checkFile($path.$bin."ev5_bringup_io_engine_test");
runTest($path.$bin."ev5_bringup_io_engine_test","-c 0 -i $instance ",$path.$csx."ev5_bringup_io_engine_test");
print(STDOUT "IO Engine test chip 1 (~20 seconds)");
runTest($path.$bin."ev5_bringup_io_engine_test","-c 1 -i $instance ",$path.$csx."ev5_bringup_io_engine_test");


# Memory test
print(STDOUT "Dram test (~2 minutes)");
checkFile($path.$csx."ev5_bringup_dram_test.csx");
checkFile($path.$bin."ev5_bringup_dram_test");
runTest($path.$bin."ev5_bringup_dram_test","-A -i $instance ",$path.$csx."ev5_bringup_dram_test");


# Data transfer test
print(STDOUT "Data transfer (with DMA) test (~15-60 seconds)");
checkFile($path.$bin."cleard_test_csapi_data_transfer_speed");
runTest($path.$bin."cleard_test_csapi_data_transfer_speed","-i $instance","");


# Interrupt test
print(STDOUT "Interrupt test (~2 seconds)");
checkFile($path.$bin."cleard_test_csapi_sig_wait_speed");
checkFile($path.$csx."cleard_test_csapi_sig_wait_speed.csx");
runTest($path.$bin."cleard_test_csapi_sig_wait_speed","-i $instance","");

#my $found_blas_files = 0;
#if( (-f $path."csx/blas_cs_processor_0.csx") && (-f $path."csx/blas_cs_processor_1.csx") && (-f $path."lib/libblas_cs.so") )
#{
#  $found_blas_files = 1;
#}
#
#if( $found_blas_files )
#{
#  # DGEMM test
#  print(STDOUT "DGEMM test (~10 seconds)");
#  checkFile($path.$bin."dgemm_pass_test");
#  my $csxl_cfg = $path.$bin."CSXL.cfg";
#  if( -f "CSXL.cfg" )
#  {
#      # it's in the current dir - override it
#      $csxl_cfg = "CSXL.cfg";
#  }
#  $ENV{'CSXL_CONFIG_FILE'}=$csxl_cfg;
#  runTest("LLDINST=$instance ".$path.$bin."dgemm_pass_test","-l 100","");
#}
#else
#{
#  if ($os ne "Windows")
#  {
#    print(STDOUT "DGEMM test requires CSXL library which is not installed.\n");
#  }
#}

sub runTest
{
  my ($cmd,$args,$csx)=@_;
  my $return;
  my $test;
  if ($os eq "Windows") 
  { 
    $cmd=~s/\//\\/g;  
    $args.="\"$csx\"";
    $test="\"$cmd\" $args >> $logfile";
  }
  else
  {
    $test="$cmd $args $csx >> $logfile";
  }
  if ($verbose==1) { print(STDOUT "\t$test"); }
  $return=system($test);
  if ($return==0) { print(STDOUT " : Pass.\n"); }
  else { print (STDOUT " : Fail ($return)\n"); }
}

sub checkFile
{
  my ($file)=@_;
  if ($os eq "Windows") 
  { 
	$file=~s/\//\\/g; 
    if ( ! (($file=~/\.csx/) || ($file=~/\.scr/)) )
    {
      $file.=".exe"; 
    }
  }
  if (!(-f $file)) { print(STDOUT "$file does not exist\n"); exit -1; }
}

sub usage
{
  print (STDOUT "\n\tUsage: $0 {-v} {-i}\n\n"); 
  exit -1;
}

==> csx600_m512_le_base_RHE4_64-2.50.tgz: opt/clearspeed/csx600_m512_le/bin/run_tests.pl <==
#!/usr/bin/perl

use strict;
use Getopt::Std;

my %opts;

getopts('vi:', \%opts) || usage();

my $path;
my $bin;
my $csx;
my $verbose;
my $logfile;
my $instance;
my $os;

if ($ENV{'OS'} eq "Windows_NT" ) 
{
  $path=$ENV{'CSHOME'}."/";
  $bin="bin/";
  $csx="csx/";
  $verbose=0;
  $logfile="test.log";
  $instance=0;
  $os="Windows";
}
else
{
  $path=$ENV{'CSHOME'}."/";
  $bin="bin/";
  $csx="csx/";
  $verbose=0;
  $logfile="test.log";
  $instance=0;
  $os="Linux";
}

if (defined $opts{'v'}) { $verbose=1; }
if (defined $opts{'i'}) { $instance=$opts{'i'}; }

if (-f $logfile) { unlink($logfile); }

# no longer needed - DMA is always on now
#$ENV{'CS_USE_DMA'} = 1;

# Order is important as test rely on the previous components working

# Check bashrc has been sourced
if ($path eq "\/") 
{
  if ($os eq "Windows") { print(STDOUT "Environment not set up correctly.\n"); }
  else { print(STDOUT "Please source bashrc !\n"); }
  exit -1; 
}

# Board existence check
# run existence check with dma off and interrupts off for max robustness
# those features are tested later
print(STDOUT "Board existence check (~2 seconds)");
checkFile($path."adbgt_scripts/board_exists.scr");
if ($os eq "Windows") 
{
  $ENV{'LLDINST'}=$instance;
  $ENV{'CS_DISABLE_DMA'} = 1;
  runTest($path.$bin."adbgt","--path \"$ENV{'CSHOME'}/adbgt_scripts\" -c board_exists.scr --noint","");
  delete $ENV{'LLDINST'};
  delete $ENV{'CS_DISABLE_DMA'};
}
else
{
  runTest("CS_DISABLE_DMA=1 LLDINST=$instance ".$path.$bin."adbgt","--path $ENV{'CSHOME'}/adbgt_scripts -c board_exists.scr --noint","");
}


# Check that csreset works properly
print(STDOUT "Driver reset test (~2 seconds)");
runTest($path.$bin."csreset","-A -i $instance -v","");


# IO engine test
print(STDOUT "IO Engine test chip 0 (~20 seconds)");
checkFile($path.$csx."ev5_bringup_io_engine_test_0.csx");
checkFile($path.$csx."ev5_bringup_io_engine_test_1.csx");
checkFile($path.$bin."ev5_bringup_io_engine_test");
runTest($path.$bin."ev5_bringup_io_engine_test","-c 0 -i $instance ",$path.$csx."ev5_bringup_io_engine_test");
print(STDOUT "IO Engine test chip 1 (~20 seconds)");
runTest($path.$bin."ev5_bringup_io_engine_test","-c 1 -i $instance ",$path.$csx."ev5_bringup_io_engine_test");


# Memory test
print(STDOUT "Dram test (~2 minutes)");
checkFile($path.$csx."ev5_bringup_dram_test.csx");
checkFile($path.$bin."ev5_bringup_dram_test");
runTest($path.$bin."ev5_bringup_dram_test","-A -i $instance ",$path.$csx."ev5_bringup_dram_test");


# Data transfer test
print(STDOUT "Data transfer (with DMA) test (~15-60 seconds)");
checkFile($path.$bin."cleard_test_csapi_data_transfer_speed");
runTest($path.$bin."cleard_test_csapi_data_transfer_speed","-i $instance","");


# Interrupt test
print(STDOUT "Interrupt test (~2 seconds)");
checkFile($path.$bin."cleard_test_csapi_sig_wait_speed");
checkFile($path.$csx."cleard_test_csapi_sig_wait_speed.csx");
runTest($path.$bin."cleard_test_csapi_sig_wait_speed","-i $instance","");

my $found_blas_files = 0;
if( (-f $path."csx/blas_cs_processor_0.csx") && (-f $path."csx/blas_cs_processor_1.csx") && (-f $path."lib/libbd_cs.so") )
{
  $found_blas_files = 1;
}

if( $found_blas_files )
{
  # DGEMM test
  print(STDOUT "DGEMM test (~10 seconds)");
  checkFile($path.$bin."dgemm_pass_test");
  my $csxl_cfg = $path.$bin."CSXL.cfg";
  if( -f "CSXL.cfg" )
  {
      # it's in the current dir - override it
      $csxl_cfg = "CSXL.cfg";
  }
  $ENV{'CSXL_CONFIG_FILE'}=$csxl_cfg;
  runTest("LLDINST=$instance ".$path.$bin."dgemm_pass_test","-l 100","");
}
else
{
  if ($os ne "Windows")
  {
    #print(STDOUT "DGEMM test requires CSXL library which is not installed.\n");
  }
}

sub runTest
{
  my ($cmd,$args,$csx)=@_;
  my $return;
  my $test;
  if ($os eq "Windows") 
  { 
    $cmd=~s/\//\\/g;  
    $args.="\"$csx\"";
    $test="\"$cmd\" $args >> $logfile";
  }
  else
  {
    $test="$cmd $args $csx >> $logfile";
  }
  if ($verbose==1) { print(STDOUT "\t$test"); }
  $return=system($test);
  if ($return==0) { print(STDOUT " : Pass.\n"); }
  else { print (STDOUT " : Fail ($return)\n"); }
}

sub checkFile
{
  my ($file)=@_;
  if ($os eq "Windows") 
  { 
	$file=~s/\//\\/g; 
    if ( ! (($file=~/\.csx/) || ($file=~/\.scr/)) )
    {
      $file.=".exe"; 
    }
  }
  if (!(-f $file)) { print(STDOUT "$file does not exist\n"); exit -1; }
}

sub usage
{
  print (STDOUT "\n\tUsage: $0 {-v} {-i}\n\n"); 
  exit -1;
}
